@@ -261,6 +261,57 @@ class OpenEuler():
         log.debug(f"Extracted RPM name: {pkg_name} | Original: {rpm} | Cleaned: {rpm_clean}")
         return pkg_name
 
+    def get_rpm_list(self,pkg_url):
+        rpm_list=[]
+        timeout = 15
+        headers = {
+            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36",
+            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
+            "Accept-Encoding": "gzip, deflate, br",
+            "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
+            "Connection": "keep-alive",
+        }
+
+        target_url = pkg_url
+
+        try:
+            with requests.Session() as session:
+                session.mount('https://', requests.adapters.HTTPAdapter(
+                    pool_connections=10,
+                    pool_maxsize=10,
+                    max_retries=3
+                ))
+                response = session.get(
+                    url=target_url,
+                    headers=headers,
+                    timeout=timeout,
+                    allow_redirects=True
+                )
+                response.raise_for_status()
+                html_content = response.text
+
+        except requests.exceptions.RequestException as e:
+            log.error(f"获取页面失败！URL: {target_url}, 错误: {str(e)}")
+            return
+
+        soup = BeautifulSoup(html_content, "html.parser")
+        # 精确匹配.rpm链接，排除父目录和空链接
+        pkg_links = soup.find_all(
+            "a",
+            href=lambda href: isinstance(href, str) and href.endswith(".rpm") and not href.startswith('../')
+        )
+
+        if not pkg_links:
+            log.error(f"页面解析失败！URL: {target_url}, 未找到任何 .rpm 包")
+            return
+        for link in pkg_links:
+            full_pkg_name = link.get("href", "").strip()
+            if full_pkg_name:  # 过滤空字符串
+                pkg_name = self.get_rpm_name_from_full_name(full_pkg_name)
+                if pkg_name not in rpm_list:
+                    rpm_list.append(pkg_name)
+        return rpm_list
+
     def get_openEuler_pkgs(
             self, os_version: str, os_arch: str, scope: str
     ) -> Generator[str, None, None]:
@@ -473,7 +524,7 @@ if __name__ == "__main__":
     # print(rpm)
     # rpm=oe.get_rpm_name_from_full_name("nodejs-lodash-valuesin-3.10.1-1.oe2403sp2.noarch.rpm")
     # print(rpm)
-    rs=oe.get_openEuler_everything_rpm_list("24.03-LTS-SP1", "x86_64")
+    # rs=oe.get_openEuler_everything_rpm_list("24.03-LTS-SP1", "x86_64")
     # print(f"everything {len(rs)} pkgs")
     # rs=oe.get_openEuler_epol_rpm_list("24.03-LTS-SP1", "x86_64")
     # print(f"epol {len(rs)} pkgs")
@@ -482,7 +533,10 @@ if __name__ == "__main__":
     # rs=oe.get_openEuler_os_rpm_list("24.03-LTS-SP1", "x86_64")
     # for rpm in rs:
     #     print(f"{rpm}")
-    print(f"os {len(rs)} pkgs")
+    # rs = oe.get_rpm_list("https://diamond.oerv.ac.cn/openruyi/riscv64/riscv64/")
+    # for rpm_name in rs:
+    #     print(f"{rpm_name}")
+    # print(f"total {len(rs)} pkgs")
     # rs=oe.get_openEuler_all_rpm_list("24.03-LTS-SP2", "x86_64")
     # print(f"total {len(rs)} pkgs")
 
